==> qore-0.8.12.3.tar.bz2: qore-0.8.12.3/docs/modules/SqlUtil/html/index.js <==
var index =
[
    [ "Introduction to the SqlUtil Module", "index.html#sqlutilintro", null ],
    [ "Overview of Functionality", "index.html#sqlutil_overview", null ],
    [ "Release Notes for the SqlUtil Module", "index.html#sqlutil_relnotes", [
      [ "SqlUtil v1.3", "index.html#sqlutilv1_3", null ],
      [ "SqlUtil v1.2", "index.html#sqlutilv1_2", null ],
      [ "SqlUtil v1.1", "index.html#sqlutilv1_1", null ],
      [ "SqlUtil v1.0", "index.html#sqlutilv1_0", null ]
    ] ],
    [ "SQL Operations", "sql_operations.html", [
      [ "Introduction to SQL Operations", "sql_operations.html#sql_operations_intro", null ],
      [ "Retrieving Data from the Database", "sql_operations.html#retrieving_data", [
        [ "Retrieving a Single Row", "sql_operations.html#find_single_row", null ],
        [ "Retrieving Multiple Rows", "sql_operations.html#find_multiple_rows", null ],
        [ "Acquiring a Row Iterator for Query Results", "sql_operations.html#get_row_iterator", null ],
        [ "Retrieving Multiple Rows in Batches", "sql_operations.html#get_rows_in_batches", null ],
        [ "Specifying Columns in Query Output", "sql_operations.html#column_spec", null ],
        [ "Complex Select Criteria", "sql_operations.html#select_option_hash", null ],
        [ "Select With Paging", "sql_operations.html#sql_paging", null ],
        [ "Check For At Least One Matching Row", "sql_operations.html#check_matching_rows", null ]
      ] ],
      [ "Inserting Data into the Database", "sql_operations.html#inserting_data", [
        [ "Inserting Data Explicitly", "sql_operations.html#inserting_data_explicitly", null ],
        [ "Inserting Data From a Select Statement", "sql_operations.html#inserting_data_from_select", null ],
        [ "Inserting Data from an Iterator Source", "sql_operations.html#inserting_data_from_iterator", null ]
      ] ],
      [ "Updating Data", "sql_operations.html#updating_data", null ],
      [ "Deleting Data", "sql_operations.html#deleting_data", null ],
      [ "Joining Tables", "sql_operations.html#joins", null ],
      [ "Where Clauses", "sql_operations.html#where_clauses", null ],
      [ "Upserting or Merging Data", "sql_operations.html#sql_upsert", [
        [ "Upsert a Single Row", "sql_operations.html#sql_upsert_single", null ],
        [ "Upserting Many Rows Using An Upsert Closure", "sql_operations.html#sql_upsert_many", null ],
        [ "Upserting Many Rows from an Iterator Source", "sql_operations.html#sql_upsert_from_iterator", null ],
        [ "Upserting Many Rows from a Select Statement", "sql_operations.html#sql_upsert_from_select", null ],
        [ "Upserting Many Rows and Deleting Unwanted Rows", "sql_operations.html#sql_upsert_with_delete", null ],
        [ "Upsert Strategies", "sql_operations.html#sql_upsert_strategies", null ]
      ] ]
    ] ],
    [ "Schema Management", "schema_management.html", [
      [ "Introduction to Schema Management", "schema_management.html#schema_management_intro", null ],
      [ "Creating New Objects", "schema_management.html#creating_new_objects", null ],
      [ "Retrieving Objects from the Database", "schema_management.html#retrieving_objects", null ],
      [ "Listing Objects", "schema_management.html#listing_objects", null ],
      [ "Working With Interdependent Tables", "schema_management.html#interdependent_tables", null ],
      [ "Aligning Schemas With a Template", "schema_management.html#aligning_schemas", [
        [ "Schema Description Hash", "schema_management.html#schema_desc_hash", null ]
      ] ],
      [ "Table Management", "schema_management.html#table_management", [
        [ "Creating New Tables", "schema_management.html#creating_new_tables", null ],
        [ "Retrieving Table Information", "schema_management.html#retrieving_table_info", null ],
        [ "Aligning Tables With a Template", "schema_management.html#aligning_tables", null ],
        [ "Table Description Hash", "schema_management.html#table_desc_hash", null ],
        [ "Column Description Hash", "schema_management.html#column_desc_hash", null ],
        [ "Primary Key Description Hash", "schema_management.html#pk_desc_hash", null ],
        [ "Foreign Constraint Description Hash", "schema_management.html#fk_desc_hash", null ],
        [ "Unique Constraint Description Hash", "schema_management.html#uk_desc_hash", null ],
        [ "Index Description Hash", "schema_management.html#index_desc_hash", null ]
      ] ],
      [ "Callbacks", "schema_management.html#callbacks", [
        [ "SQL Info CallBack Closure or Call Ceference", "schema_management.html#info_callback", null ],
        [ "SQL Raw/DDL CallBack Closure or Call Ceference", "schema_management.html#sql_callback", null ],
        [ "SQL CallBack Executed Flag", "schema_management.html#sql_callback_executed", null ],
        [ "SQL Operation Callback Closure or Call Reference", "schema_management.html#sqlarg_callback", null ],
        [ "Upsert Info Callback", "schema_management.html#upsert_info_callback", null ],
        [ "Insert Info Callback", "schema_management.html#insert_info_callback", null ]
      ] ]
    ] ],
    [ "DBA Management", "dba_management.html", [
      [ "Introduction to DB Administration", "dba_management.html#dba_management_intro", null ],
      [ "Index Management", "dba_management.html#dba_indexes", [
        [ "Oracle Options", "dba_management.html#dba_indexes_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_indexes_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_indexes_mysql", null ]
      ] ],
      [ "Database Statistics", "dba_management.html#dba_statistics", [
        [ "Oracle Options", "dba_management.html#dba_statistics_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_statistics_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_statistics_mysql", null ]
      ] ],
      [ "Space Management", "dba_management.html#dba_space_management", [
        [ "Oracle Options", "dba_management.html#dba_space_management_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_space_management_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_space_management_mysql", null ]
      ] ]
    ] ]
];

==> qore-0.8.13.2.tar.bz2: qore-0.8.13.2/docs/modules/SqlUtil/html/index.js <==
var index =
[
    [ "Introduction to the SqlUtil Module", "index.html#sqlutilintro", null ],
    [ "Overview of Functionality", "index.html#sqlutil_overview", null ],
    [ "Release Notes for the SqlUtil Module", "index.html#sqlutil_relnotes", [
      [ "SqlUtil v1.4.2", "index.html#sqlutilv1_4_2", null ],
      [ "SqlUtil v1.4.1", "index.html#sqlutilv1_4_1", null ],
      [ "SqlUtil v1.4", "index.html#sqlutilv1_4", null ],
      [ "SqlUtil v1.3.4", "index.html#sqlutilv1_3_4", null ],
      [ "SqlUtil v1.3.3", "index.html#sqlutilv1_3_3", null ],
      [ "SqlUtil v1.3.2", "index.html#sqlutilv1_3_2", null ],
      [ "SqlUtil v1.3.1", "index.html#sqlutilv1_3_1", null ],
      [ "SqlUtil v1.3", "index.html#sqlutilv1_3", null ],
      [ "SqlUtil v1.2", "index.html#sqlutilv1_2", null ],
      [ "SqlUtil v1.1", "index.html#sqlutilv1_1", null ],
      [ "SqlUtil v1.0", "index.html#sqlutilv1_0", null ]
    ] ],
    [ "SQL Operations", "sql_operations.html", [
      [ "Introduction to SQL Operations", "sql_operations.html#sql_operations_intro", null ],
      [ "Retrieving Data from the Database", "sql_operations.html#retrieving_data", [
        [ "Retrieving a Single Row", "sql_operations.html#find_single_row", null ],
        [ "Retrieving Multiple Rows", "sql_operations.html#find_multiple_rows", null ],
        [ "Acquiring a Row Iterator for Query Results", "sql_operations.html#get_row_iterator", null ],
        [ "Retrieving Multiple Rows in Batches", "sql_operations.html#get_rows_in_batches", null ],
        [ "Specifying Columns in Query Output", "sql_operations.html#column_spec", null ],
        [ "Complex Select Criteria", "sql_operations.html#select_option_hash", [
          [ "Select Option \"alias\"", "sql_operations.html#select_option_alias", null ],
          [ "Select Option \"comment\"", "sql_operations.html#select_option_comment", null ],
          [ "Select Option \"hint\"", "sql_operations.html#select_option_hint", null ],
          [ "Select Option \"columns\"", "sql_operations.html#select_option_columns", null ],
          [ "Select Option \"where\"", "sql_operations.html#select_option_where", null ],
          [ "Select Option \"orderby\"", "sql_operations.html#select_option_orderby", null ],
          [ "Select Option \"desc\"", "sql_operations.html#select_option_desc", null ],
          [ "Select Option \"limit\"", "sql_operations.html#select_option_limit", null ],
          [ "Select Option \"offset\"", "sql_operations.html#select_option_offset", null ],
          [ "Select Option \"join\"", "sql_operations.html#select_option_join", null ],
          [ "Select Option \"groupby\"", "sql_operations.html#select_option_groupby", null ],
          [ "Select Option \"having\"", "sql_operations.html#select_option_having", null ],
          [ "Select Option \"superquery\"", "sql_operations.html#select_option_superquery", null ],
          [ "Select Option \"forupdate\"", "sql_operations.html#select_option_forupdate", null ]
        ] ],
        [ "Select With Paging", "sql_operations.html#sql_paging", null ],
        [ "Check For At Least One Matching Row", "sql_operations.html#check_matching_rows", null ]
      ] ],
      [ "Inserting Data into the Database", "sql_operations.html#inserting_data", [
        [ "Inserting Data Explicitly", "sql_operations.html#inserting_data_explicitly", null ],
        [ "Inserting Data From a Select Statement", "sql_operations.html#inserting_data_from_select", null ],
        [ "Inserting Data from an Iterator Source", "sql_operations.html#inserting_data_from_iterator", null ]
      ] ],
      [ "Updating Data", "sql_operations.html#updating_data", null ],
      [ "Deleting Data", "sql_operations.html#deleting_data", null ],
      [ "Joining Tables", "sql_operations.html#joins", null ],
      [ "Where Clauses", "sql_operations.html#where_clauses", null ],
      [ "Upserting or Merging Data", "sql_operations.html#sql_upsert", [
        [ "Upsert a Single Row", "sql_operations.html#sql_upsert_single", null ],
        [ "Upserting Many Rows Using An Upsert Closure", "sql_operations.html#sql_upsert_many", null ],
        [ "Upserting Many Rows from an Iterator Source", "sql_operations.html#sql_upsert_from_iterator", null ],
        [ "Upserting Many Rows from a Select Statement", "sql_operations.html#sql_upsert_from_select", null ],
        [ "Upserting Many Rows and Deleting Unwanted Rows", "sql_operations.html#sql_upsert_with_delete", null ],
        [ "Upsert Strategies", "sql_operations.html#sql_upsert_strategies", null ]
      ] ]
    ] ],
    [ "Schema Management", "schema_management.html", [
      [ "Introduction to Schema Management", "schema_management.html#schema_management_intro", null ],
      [ "Creating New Objects", "schema_management.html#creating_new_objects", null ],
      [ "Retrieving Objects from the Database", "schema_management.html#retrieving_objects", null ],
      [ "Listing Objects", "schema_management.html#listing_objects", null ],
      [ "Working With Interdependent Tables", "schema_management.html#interdependent_tables", null ],
      [ "Aligning Schemas With a Template", "schema_management.html#aligning_schemas", [
        [ "Schema Description Hash", "schema_management.html#schema_desc_hash", null ]
      ] ],
      [ "Table Management", "schema_management.html#table_management", [
        [ "Creating New Tables", "schema_management.html#creating_new_tables", null ],
        [ "Retrieving Table Information", "schema_management.html#retrieving_table_info", null ],
        [ "Aligning Tables With a Template", "schema_management.html#aligning_tables", null ],
        [ "Table Description Hash", "schema_management.html#table_desc_hash", null ],
        [ "Column Description Hash", "schema_management.html#column_desc_hash", null ],
        [ "Primary Key Description Hash", "schema_management.html#pk_desc_hash", null ],
        [ "Foreign Constraint Description Hash", "schema_management.html#fk_desc_hash", null ],
        [ "Unique Constraint Description Hash", "schema_management.html#uk_desc_hash", null ],
        [ "Index Description Hash", "schema_management.html#index_desc_hash", null ]
      ] ],
      [ "Callbacks", "schema_management.html#callbacks", [
        [ "SQL Info CallBack Closure or Call Ceference", "schema_management.html#info_callback", null ],
        [ "SQL Raw/DDL CallBack Closure or Call Ceference", "schema_management.html#sql_callback", null ],
        [ "SQL CallBack Executed Flag", "schema_management.html#sql_callback_executed", null ],
        [ "SQL Operation Callback Closure or Call Reference", "schema_management.html#sqlarg_callback", null ],
        [ "Upsert Info Callback", "schema_management.html#upsert_info_callback", null ],
        [ "Insert Info Callback", "schema_management.html#insert_info_callback", null ]
      ] ]
    ] ],
    [ "DBA Management", "dba_management.html", [
      [ "Introduction to DB Administration", "dba_management.html#dba_management_intro", null ],
      [ "Index Management", "dba_management.html#dba_indexes", [
        [ "Oracle Options", "dba_management.html#dba_indexes_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_indexes_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_indexes_mysql", null ]
      ] ],
      [ "Database Statistics", "dba_management.html#dba_statistics", [
        [ "Oracle Options", "dba_management.html#dba_statistics_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_statistics_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_statistics_mysql", null ]
      ] ],
      [ "Space Management", "dba_management.html#dba_space_management", [
        [ "Oracle Options", "dba_management.html#dba_space_management_oracle", null ],
        [ "PostgreSQL Options", "dba_management.html#dba_space_management_pgsql", null ],
        [ "MySQL Options", "dba_management.html#dba_space_management_mysql", null ]
      ] ]
    ] ]
];
